@@ -41,9 +41,9 @@
 
 #define WHEEL_EVENT_FACTOR 1.5
 
-static USHORT ImplGetModifierMask( unsigned int nMask )
+static sal_uInt16 ImplGetModifierMask( unsigned int nMask )
 {
-    USHORT nRet = 0;
+    sal_uInt16 nRet = 0;
     if( (nMask & NSShiftKeyMask) != 0 )
         nRet |= KEY_SHIFT;
     if( (nMask & NSControlKeyMask) != 0 )
@@ -55,9 +55,9 @@ static USHORT ImplGetModifierMask( unsigned int nMask )
     return nRet;
 }
 
-static USHORT ImplMapCharCode( sal_Unicode aCode )
+static sal_uInt16 ImplMapCharCode( sal_Unicode aCode )
 {
-    static USHORT aKeyCodeMap[ 128 ] =
+    static sal_uInt16 aKeyCodeMap[ 128 ] =
     {
         0, 0, 0, 0, 0, 0, 0, 0,
         KEY_BACKSPACE, KEY_TAB, KEY_RETURN, 0, 0, KEY_RETURN, 0, 0,
@@ -85,7 +85,7 @@ static USHORT ImplMapCharCode( sal_Unicode aCode )
     // tab alone is reported as 0x09 (as expected) but shift-tab is
     // reported as 0x19 (end of medium)
     
-    static USHORT aFunctionKeyCodeMap[ 128 ] =
+    static sal_uInt16 aFunctionKeyCodeMap[ 128 ] =
     {
         KEY_UP, KEY_DOWN, KEY_LEFT, KEY_RIGHT, KEY_F1, KEY_F2, KEY_F3, KEY_F4,
         KEY_F5, KEY_F6, KEY_F7, KEY_F8, KEY_F9, KEY_F10, KEY_F11, KEY_F12,
@@ -105,7 +105,7 @@ static USHORT ImplMapCharCode( sal_Unicode aCode )
         0, 0, 0, 0, 0, 0, 0, 0
     };
     
-    USHORT nKeyCode = 0;
+    sal_uInt16 nKeyCode = 0;
     if( aCode < SAL_N_ELEMENTS( aKeyCodeMap)  )
         nKeyCode = aKeyCodeMap[ aCode ];
     else if( aCode >= 0xf700 && aCode < 0xf780 )
@@ -117,12 +117,12 @@ static USHORT ImplMapCharCode( sal_Unicode aCode )
 static AquaSalFrame* s_pMouseFrame = NULL;
 // store the last pressed button for enter/exit events
 // which lack that information
-static USHORT s_nLastButton = 0;
+static sal_uInt16 s_nLastButton = 0;
 
 // combinations of keys we need to handle ourselves
 static const struct ExceptionalKey
 {
-    const USHORT        nKeyCode;
+    const sal_uInt16        nKeyCode;
     const unsigned int  nModifierMask;
 } aExceptionalKeys[] =
 {
@@ -155,7 +155,9 @@ static AquaSalFrame* getMouseContainerFrame()
     NSRect aRect = { { pFrame->maGeometry.nX, pFrame->maGeometry.nY },
                      { pFrame->maGeometry.nWidth, pFrame->maGeometry.nHeight } };
     pFrame->VCLToCocoa( aRect );
-    return [super initWithContentRect: aRect styleMask: mpFrame->getStyleMask() backing: NSBackingStoreBuffered defer: NO ];
+    NSWindow* pNSWindow = [super initWithContentRect: aRect styleMask: mpFrame->getStyleMask() backing: NSBackingStoreBuffered defer: NO ];
+    [pNSWindow useOptimizedDrawing: YES]; // OSX recommendation when there are no overlapping subviews within the receiver
+    return pNSWindow;
 }
 
 -(AquaSalFrame*)getSalFrame
@@ -163,16 +165,30 @@ static AquaSalFrame* getMouseContainerFrame()
     return mpFrame;
 }
 
--(MacOSBOOL)containsMouse
+-(void)displayIfNeeded
+{
+    if( GetSalData() && GetSalData()->mpFirstInstance )
+    {
+        osl::SolarMutex* pMutex = GetSalData()->mpFirstInstance->GetYieldMutex();
+        if( pMutex )
+        {
+            pMutex->acquire();
+            [super displayIfNeeded];
+            pMutex->release();
+        }
+    }
+}
+
+-(BOOL)containsMouse
 {
     // is this event actually inside that NSWindow ?
     NSPoint aPt = [NSEvent mouseLocation];
     NSRect aFrameRect = [self frame];
-    MacOSBOOL bInRect = NSPointInRect( aPt, aFrameRect );
+    BOOL bInRect = NSPointInRect( aPt, aFrameRect );
     return bInRect;
 }
 
--(MacOSBOOL)canBecomeKeyWindow
+-(BOOL)canBecomeKeyWindow
 {
     if( (mpFrame->mnStyle & 
             ( SAL_FRAME_STYLE_FLOAT                 |
@@ -195,7 +211,7 @@ static AquaSalFrame* getMouseContainerFrame()
 
     if( mpFrame && AquaSalFrame::isAlive( mpFrame ) )
     {
-        static const ULONG nGuessDocument = SAL_FRAME_STYLE_MOVEABLE|
+        static const sal_uLong nGuessDocument = SAL_FRAME_STYLE_MOVEABLE|
                                             SAL_FRAME_STYLE_SIZEABLE|
                                             SAL_FRAME_STYLE_CLOSEABLE;
         
@@ -285,11 +301,11 @@ static AquaSalFrame* getMouseContainerFrame()
     }
 }
 
--(MacOSBOOL)windowShouldClose: (NSNotification*)pNotification
+-(BOOL)windowShouldClose: (NSNotification*)pNotification
 {
     YIELD_GUARD;
 
-    MacOSBOOL bRet = YES;
+    BOOL bRet = YES;
     if( mpFrame && AquaSalFrame::isAlive( mpFrame ) )
     {
         // #i84461# end possible input
@@ -332,12 +348,12 @@ static AquaSalFrame* getMouseContainerFrame()
   [mDraggingDestinationHandler draggingExited: sender];
 }
 
--(MacOSBOOL)prepareForDragOperation:(id <NSDraggingInfo>)sender
+-(BOOL)prepareForDragOperation:(id <NSDraggingInfo>)sender
 {
   return [mDraggingDestinationHandler prepareForDragOperation: sender];
 }
 
--(MacOSBOOL)performDragOperation:(id <NSDraggingInfo>)sender
+-(BOOL)performDragOperation:(id <NSDraggingInfo>)sender
 {
   return [mDraggingDestinationHandler performDragOperation: sender];
 }
@@ -383,6 +399,11 @@ static AquaSalFrame* getMouseContainerFrame()
     return self;
 }
 
+-(AquaSalFrame*)getSalFrame
+{
+    return mpFrame;
+}
+
 -(void)resetCursorRects
 {
     if( mpFrame && AquaSalFrame::isAlive( mpFrame ) )
@@ -393,17 +414,17 @@ static AquaSalFrame* getMouseContainerFrame()
     }
 }
 
--(MacOSBOOL)acceptsFirstResponder
+-(BOOL)acceptsFirstResponder
 {
     return YES;
 }
 
--(MacOSBOOL)acceptsFirstMouse: (NSEvent*)pEvent
+-(BOOL)acceptsFirstMouse: (NSEvent*)pEvent
 {
     return YES;
 }
 
--(MacOSBOOL)isOpaque
+-(BOOL)isOpaque
 {
     return mpFrame ? (mpFrame->getClipPath() != 0 ? NO : YES) : YES;
 }
@@ -451,7 +472,7 @@ private:
     }
 }
 
--(void)sendMouseEventToFrame: (NSEvent*)pEvent button:(USHORT)nButton eventtype:(USHORT)nEvent
+-(void)sendMouseEventToFrame: (NSEvent*)pEvent button:(sal_uInt16)nButton eventtype:(sal_uInt16)nEvent
 {
     YIELD_GUARD;
 
@@ -507,13 +528,13 @@ private:
     
     if( pDispatchFrame && AquaSalFrame::isAlive( pDispatchFrame ) )
     {
-        pDispatchFrame->mnLastEventTime = static_cast<ULONG>( [pEvent timestamp] * 1000.0 );
+        pDispatchFrame->mnLastEventTime = static_cast<sal_uLong>( [pEvent timestamp] * 1000.0 );
         pDispatchFrame->mnLastModifierFlags = [pEvent modifierFlags];
 
         NSPoint aPt = [NSEvent mouseLocation];
         pDispatchFrame->CocoaToVCL( aPt );
         
-        USHORT nModMask = ImplGetModifierMask( [pEvent modifierFlags] );
+        sal_uInt16 nModMask = ImplGetModifierMask( [pEvent modifierFlags] );
         // #i82284# emulate ctrl left
         if( nModMask == KEY_MOD3 && nButton == MOUSE_LEFT )
         {
@@ -574,8 +595,11 @@ private:
 -(void)mouseEntered: (NSEvent*)pEvent
 {
     s_pMouseFrame = mpFrame;
-    
-    [self sendMouseEventToFrame:pEvent button:s_nLastButton eventtype:SALEVENT_MOUSEMOVE];
+ 
+    // #i107215# the only mouse events we get when inactive are enter/exit
+    // actually we would like to have all of them, but better none than some
+    if( [NSApp isActive] )
+        [self sendMouseEventToFrame:pEvent button:s_nLastButton eventtype:SALEVENT_MOUSEMOVE];
 }
 
 -(void)mouseExited: (NSEvent*)pEvent
@@ -583,7 +607,10 @@ private:
     if( s_pMouseFrame == mpFrame )
         s_pMouseFrame = NULL;
 
-    [self sendMouseEventToFrame:pEvent button:s_nLastButton eventtype:SALEVENT_MOUSELEAVE];
+    // #i107215# the only mouse events we get when inactive are enter/exit
+    // actually we would like to have all of them, but better none than some
+    if( [NSApp isActive] )
+        [self sendMouseEventToFrame:pEvent button:s_nLastButton eventtype:SALEVENT_MOUSELEAVE];
 }
 
 -(void)rightMouseDown: (NSEvent*)pEvent
@@ -641,7 +668,7 @@ private:
     if( AquaSalFrame::isAlive( mpFrame ) )
 	{
 		const NSTimeInterval fMagnifyTime = [pEvent timestamp];
-        mpFrame->mnLastEventTime = static_cast<ULONG>( fMagnifyTime * 1000.0 );
+        mpFrame->mnLastEventTime = static_cast<sal_uLong>( fMagnifyTime * 1000.0 );
         mpFrame->mnLastModifierFlags = [pEvent modifierFlags];
 
         // check if this is a new series of magnify events
@@ -712,7 +739,7 @@ private:
     
     if( AquaSalFrame::isAlive( mpFrame ) )
     {
-        mpFrame->mnLastEventTime = static_cast<ULONG>( [pEvent timestamp] * 1000.0 );
+        mpFrame->mnLastEventTime = static_cast<sal_uLong>( [pEvent timestamp] * 1000.0 );
         mpFrame->mnLastModifierFlags = [pEvent modifierFlags];
         
         // merge pending scroll wheel events
@@ -772,7 +799,7 @@ private:
     
     if( AquaSalFrame::isAlive( mpFrame ) )
     {
-        mpFrame->mnLastEventTime = static_cast<ULONG>( [pEvent timestamp] * 1000.0 );
+        mpFrame->mnLastEventTime = static_cast<sal_uLong>( [pEvent timestamp] * 1000.0 );
         mpFrame->mnLastModifierFlags = [pEvent modifierFlags];
 
         // merge pending scroll wheel events
@@ -844,7 +871,7 @@ private:
         mbNeedSpecialKeyHandle = false;
         mbKeyHandled = false;
 
-        mpFrame->mnLastEventTime = static_cast<ULONG>( [pEvent timestamp] * 1000.0 );
+        mpFrame->mnLastEventTime = static_cast<sal_uLong>( [pEvent timestamp] * 1000.0 );
         mpFrame->mnLastModifierFlags = [pEvent modifierFlags];
         
         if( ! [self handleKeyDownException: pEvent] )
@@ -857,7 +884,7 @@ private:
     }
 }
 
--(MacOSBOOL)handleKeyDownException:(NSEvent*)pEvent
+-(BOOL)handleKeyDownException:(NSEvent*)pEvent
 {
     // check for a very special set of modified characters
     NSString* pUnmodifiedString = [pEvent charactersIgnoringModifiers]; 
@@ -875,7 +902,7 @@ private:
                 return YES;
         }
         unichar keyChar = [pUnmodifiedString characterAtIndex: 0];
-        USHORT nKeyCode = ImplMapCharCode( keyChar );
+        sal_uInt16 nKeyCode = ImplMapCharCode( keyChar );
         
         // Caution: should the table grow to more than 5 or 6 entries,
         // we must consider moving it to a kind of hash map
@@ -901,7 +928,7 @@ private:
     
     if( AquaSalFrame::isAlive( mpFrame ) )
     {
-        mpFrame->mnLastEventTime = static_cast<ULONG>( [pEvent timestamp] * 1000.0 );
+        mpFrame->mnLastEventTime = static_cast<sal_uLong>( [pEvent timestamp] * 1000.0 );
         mpFrame->mnLastModifierFlags = [pEvent modifierFlags];
     }
 }
@@ -931,7 +958,7 @@ private:
 				! [self hasMarkedText ]
                 )
             {
-                USHORT nKeyCode = ImplMapCharCode( aCharCode );
+                sal_uInt16 nKeyCode = ImplMapCharCode( aCharCode );
                 unsigned int nLastModifiers = mpFrame->mnLastModifierFlags;
 
                 // #i99567#
@@ -1307,18 +1334,18 @@ private:
     }
 }
 
--(MacOSBOOL)sendKeyInputAndReleaseToFrame: (USHORT)nKeyCode character: (sal_Unicode)aChar
+-(BOOL)sendKeyInputAndReleaseToFrame: (sal_uInt16)nKeyCode character: (sal_Unicode)aChar
 {
     return [self sendKeyInputAndReleaseToFrame: nKeyCode character: aChar modifiers: mpFrame->mnLastModifierFlags];
 }
 
--(MacOSBOOL)sendKeyInputAndReleaseToFrame: (USHORT)nKeyCode character: (sal_Unicode)aChar modifiers: (unsigned int)nMod
+-(BOOL)sendKeyInputAndReleaseToFrame: (sal_uInt16)nKeyCode character: (sal_Unicode)aChar modifiers: (unsigned int)nMod
 {
     return [self sendKeyToFrameDirect: nKeyCode character: aChar modifiers: nMod] ||
            [self sendSingleCharacter: mpLastEvent];
 }
 
--(MacOSBOOL)sendKeyToFrameDirect: (USHORT)nKeyCode  character: (sal_Unicode)aChar modifiers: (unsigned int)nMod
+-(BOOL)sendKeyToFrameDirect: (sal_uInt16)nKeyCode  character: (sal_Unicode)aChar modifiers: (unsigned int)nMod
 {
     YIELD_GUARD;
     
@@ -1341,20 +1368,20 @@ private:
 }
 
 
--(MacOSBOOL)sendSingleCharacter: (NSEvent *)pEvent
+-(BOOL)sendSingleCharacter: (NSEvent *)pEvent
 {
     NSString* pUnmodifiedString = [pEvent charactersIgnoringModifiers]; 
 
     if( pUnmodifiedString && [pUnmodifiedString length] == 1 )
     {
         unichar keyChar = [pUnmodifiedString characterAtIndex: 0];
-        USHORT nKeyCode = ImplMapCharCode( keyChar );
+        sal_uInt16 nKeyCode = ImplMapCharCode( keyChar );
         if( nKeyCode != 0 )
         {
             // don't send unicodes in the private use area
             if( keyChar >= 0xf700 && keyChar < 0xf780 )
                 keyChar = 0;
-            MacOSBOOL bRet = [self sendKeyToFrameDirect: nKeyCode character: keyChar modifiers: mpFrame->mnLastModifierFlags];
+            BOOL bRet = [self sendKeyToFrameDirect: nKeyCode character: keyChar modifiers: mpFrame->mnLastModifierFlags];
             mbInKeyInput = false;
 
             return bRet;
@@ -1370,9 +1397,9 @@ private:
     return [NSArray arrayWithObjects:NSUnderlineStyleAttributeName, nil];
 }
 
-- (MacOSBOOL)hasMarkedText
+- (BOOL)hasMarkedText
 {
-    MacOSBOOL bHasMarkedText;
+    BOOL bHasMarkedText;
 
     bHasMarkedText = ( mMarkedRange.location != NSNotFound ) &&
                      ( mMarkedRange.length != 0 );
@@ -1439,7 +1466,7 @@ private:
     if( len > 0 ) {
         NSString *pString = [aString string];
         OUString aInsertString( GetOUString( pString ) );
-        std::vector<USHORT> aInputFlags = std::vector<USHORT>( std::max( 1, len ), 0 );
+        std::vector<sal_uInt16> aInputFlags = std::vector<sal_uInt16>( std::max( 1, len ), 0 );
         for ( int i = 0; i < len; i++ )
         {
             unsigned int nUnderlineValue;
@@ -1598,12 +1625,12 @@ private:
   [mDraggingDestinationHandler draggingExited: sender];
 }
 
--(MacOSBOOL)prepareForDragOperation:(id <NSDraggingInfo>)sender
+-(BOOL)prepareForDragOperation:(id <NSDraggingInfo>)sender
 {
   return [mDraggingDestinationHandler prepareForDragOperation: sender];
 }
 
--(MacOSBOOL)performDragOperation:(id <NSDraggingInfo>)sender
+-(BOOL)performDragOperation:(id <NSDraggingInfo>)sender
 {
   return [mDraggingDestinationHandler performDragOperation: sender];
 }
